@@ -27,6 +27,7 @@ import javax.swing.JScrollPane;
 import javax.swing.JTable;
 import javax.swing.JTextField;
 import javax.swing.ListSelectionModel;
+import javax.swing.SwingUtilities;
 import javax.swing.UIManager;
 import javax.swing.border.Border;
 import javax.swing.event.CellEditorListener;
@@ -152,7 +153,12 @@ public class AlignmentListInputEditor extends ListInputEditor {
         new FileDrop(null, scrollPane, focusBorder, new FileDrop.Listener() {
             @Override
 			public void filesDropped(java.io.File[] files) {
-                addFiles(files);
+            	SwingUtilities.invokeLater(new Runnable() {
+					@Override
+					public void run() {
+						addItem(files);
+					}
+				});
             }   // end filesDropped
         }); // end FileDrop.Listener
 
@@ -213,46 +219,6 @@ public class AlignmentListInputEditor extends ListInputEditor {
         return buttonBox;
     }
 
-    private void addFiles(File[] fileArray) {
-        List<BEASTInterface> beastObjects = null;
-
-        List<BeautiAlignmentProvider> providers = doc.beautiConfig.alignmentProvider;
-        BeautiAlignmentProvider selectedProvider = null;
-        if (providers.size() == 1) {
-            selectedProvider = providers.get(0);
-        } else {
-            selectedProvider = (BeautiAlignmentProvider) JOptionPane.showInputDialog(this, "Select what to add",
-                    "Add partition",
-                    JOptionPane.QUESTION_MESSAGE, null, providers.toArray(),
-                    providers.get(0));
-            if (selectedProvider == null) {
-                return;
-            }
-        }
-
-        beastObjects = selectedProvider.getAlignments(doc, fileArray);
-
-        // create taxon sets, if any
-        if (beastObjects != null) {
-	        for (BEASTInterface o : beastObjects) {
-	        	if (o instanceof Alignment) {
-	        		try {
-						BeautiDoc.createTaxonSet((Alignment) o, doc);
-					} catch (Exception e) {
-						e.printStackTrace();
-					}
-	        	}
-	        }
-        }
-
-        // Component c = this;
-        if (beastObjects != null) {
-            refreshPanel();
-        }
-    }
-
-
-
 	/**
      * This method just adds the two buttons (with add()) and does not add any glue or struts before or after.
      * @param box
@@ -1089,13 +1055,17 @@ public class AlignmentListInputEditor extends ListInputEditor {
 
 	@Override
 	protected void addItem() {
-		List<BEASTInterface> beastObjects = doc.beautiConfig.selectAlignments(doc, this);
+		addItem(null);
+	} // addItem
+
+	private void addItem(File[] fileArray) {
+		List<BEASTInterface> beastObjects = doc.beautiConfig.selectAlignments(doc, this, fileArray);
 
 		// Component c = this;
 		if (beastObjects != null) {
 			refreshPanel();
 		}
-	} // addItem
+	}
 
 	void delItem() {
 		int[] selected = getTableRowSelection();
