@@ -325,8 +325,8 @@ public class LogCombiner extends LogAnalyser {
 	                	} else {
 	                		state += m_nSampleInterval;
 	                	}
-	                    str = str.replaceAll("^tree STATE_[^\\s=]*", "");
-	                	m_out.print("tree STATE_" + state + " =" + str);
+	                    str = str.replaceAll("^tree STATE_[^\\s]*", "");
+	                	m_out.print("tree STATE_" + state + str);
 	                	m_out.println();
                 	}
                 }
@@ -539,8 +539,10 @@ public class LogCombiner extends LogAnalyser {
                 String titleString = "<html><center><p>LogCombiner<br>" +
                         "Version " + version.getVersionString() + ", " + version.getDateString() + "</p></center></html>";
 
-                //ConsoleApplication consoleApp =
                 new ConsoleApplication(nameString, aboutString, icon, true);
+                Log.info = System.out;
+                Log.warning = System.out;
+                Log.err = System.err;
 
                 combiner.printTitle(aboutString);
 
