@@ -25,23 +25,8 @@
 
 package beast.app.treeannotator;
 
-import java.io.BufferedReader;
-import java.io.File;
-import java.io.FileNotFoundException;
-import java.io.FileOutputStream;
-import java.io.FileReader;
-import java.io.IOException;
-import java.io.PrintStream;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.BitSet;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Locale;
-import java.util.Map;
-import java.util.Set;
-import java.util.SortedSet;
+import java.io.*;
+import java.util.*;
 
 import javax.swing.JFrame;
 
@@ -87,22 +72,85 @@ public class TreeAnnotator {
     	abstract boolean hasNext();
     	abstract Tree next() throws IOException;
     	abstract void reset() throws IOException;
+
+
+        String inputFileName;
+        int burninCount = 0;
+        int totalTrees = 0;
+        boolean isNexus = true;
+
+        /** determine number of trees in the file,
+    	 * and number of trees to skip as burnin
+    	 * @throws IOException
+    	 * @throws FileNotFoundException **/
+    	void countTrees(int burninPercentage) throws IOException  {
+            BufferedReader fin = new BufferedReader(new FileReader(new File(inputFileName)));
+            if (!fin.ready()) {
+            	throw new IOException("File appears empty");
+            }
+        	String str = fin.readLine();
+            if (!str.toUpperCase().trim().startsWith("#NEXUS")) {
+            	// the file contains a list of Newick trees instead of a list in Nexus format
+            	isNexus = false;
+            	if (str.trim().length() > 0) {
+            		totalTrees = 1;
+            	}
+            }
+            while (fin.ready()) {
+            	str = fin.readLine();
+                if (isNexus) {
+                    if (str.trim().toLowerCase().startsWith("tree ")) {
+                    	totalTrees++;
+                    }
+                } else if (str.trim().length() > 0) {
+            		totalTrees++;
+                }
+            }
+            fin.close();
+
+            burninCount = Math.max(0, (burninPercentage * totalTrees)/100);
+
+            progressStream.println("Processing " + (totalTrees - burninCount) + " trees from file" +
+                    (burninPercentage > 0 ? " after ignoring first " + burninPercentage + "% = " + burninCount + " trees." : "."));
+		}
+
     }    
     
     class FastTreeSet extends TreeSet {
     	int current = 0;
     	Tree [] trees;
-    	
+
     	public FastTreeSet(String inputFileName, int burninPercentage) throws IOException  {
-            progressStream.println("0              25             50             75            100");
-            progressStream.println("|--------------|--------------|--------------|--------------|");
-    		TreeSetParser parser = new TreeSetParser(burninPercentage, false);
-	      	Node [] roots = parser.parseFile(inputFileName);
-	      	trees = new Tree[roots.length];
-	      	int i = 0;
-	      	for (Node root : roots) {
-	      		trees[i++] = new Tree(root);
-	      	}
+            this.inputFileName = inputFileName;
+            countTrees(burninPercentage);
+
+            List<Tree> parsedTrees;
+            if (isNexus) {
+                NexusParser nexusParser = new NexusParser();
+                nexusParser.parseFile(new File(inputFileName));
+                parsedTrees = nexusParser.trees;
+            } else {
+                BufferedReader fin = new BufferedReader(new FileReader(inputFileName));
+                parsedTrees = new ArrayList<>();
+                while (fin.ready()) {
+                    String line = fin.readLine().trim();
+
+                    Tree thisTree;
+                    try {
+                        thisTree = new TreeParser(null, line, 0, false);
+                    } catch (ArrayIndexOutOfBoundsException e) {
+                        thisTree = new TreeParser(null, line, 1, false);
+                    }
+
+                    parsedTrees.add(thisTree);
+                }
+                fin.close();
+            }
+
+            int treesToUse = parsedTrees.size() - burninCount;
+	      	trees = new Tree[treesToUse];
+            for (int i=burninCount; i<parsedTrees.size(); i++)
+                trees[i-burninCount] = parsedTrees.get(i);
 		}
 
 		@Override
@@ -127,55 +175,19 @@ public class TreeAnnotator {
     	int lineNr;
         public Map<String, String> translationMap = null;
         public List<String> taxa;
-    	
-        int burninCount = 0;
-        int totalTrees = 0;
-        boolean isNexus = true;
-        BufferedReader fin;
-        String inputFileName;
+
         // label count origin for NEXUS trees
         int origin = -1;
-       
+
+        BufferedReader fin;
+
         MemoryFriendlyTreeSet(String inputFileName, int burninPercentage) throws IOException  {
     		this.inputFileName = inputFileName;
-    		init(burninPercentage);
-        	progressStream.println("Processing " + (totalTrees - burninCount) + " trees from file" +
-                    (burninPercentage > 0 ? " after ignoring first " + burninPercentage + "% = " + burninCount + " trees." : "."));
-    		
-    		
+    		countTrees(burninPercentage);
+
+            fin = new BufferedReader(new FileReader(inputFileName));
     	}
 
-    	/** determine number of trees in the file,
-    	 * and number of trees to skip as burnin 
-    	 * @throws IOException 
-    	 * @throws FileNotFoundException **/
-    	private void init(int burninPercentage) throws IOException  {
-            fin = new BufferedReader(new FileReader(new File(inputFileName)));
-            if (!fin.ready()) {
-            	throw new IOException("File appears empty");
-            }
-        	String str = nextLine();
-            if (!str.toUpperCase().trim().startsWith("#NEXUS")) {
-            	// the file contains a list of Newick trees instead of a list in Nexus format
-            	isNexus = false;
-            	if (str.trim().length() > 0) {
-            		totalTrees = 1;
-            	}
-            }
-            while (fin.ready()) {
-            	str = nextLine();
-                if (isNexus) {
-                    if (str.trim().toLowerCase().startsWith("tree ")) {
-                    	totalTrees++;
-                    }
-                } else if (str.trim().length() > 0) {
-            		totalTrees++;
-                }            	
-            }
-            fin.close();
-            
-            burninCount = Math.max(0, (burninPercentage * totalTrees)/100);
-		}
 
     	@Override
 		void reset() throws FileNotFoundException  {
@@ -415,7 +427,7 @@ public class TreeAnnotator {
 
 
     // Messages to stderr, output to stdout
-    private static PrintStream progressStream = Log.err;
+    static PrintStream progressStream = Log.err;
 
 //    private final String location1Attribute = "longLat1";
 //    private final String location2Attribute = "longLat2";
@@ -445,10 +457,6 @@ public class TreeAnnotator {
         totalTrees = 10000;
         totalTreesUsed = 0;
 
-        //progressStream.println("Reading trees (bar assumes 10,000 trees)...");
-
-        int stepSize = Math.max(totalTrees / 60, 1);
-
         try {
         	if (lowMemory) {
         		treeSet = new MemoryFriendlyTreeSet(inputFileName, burninPercentage);
@@ -461,7 +469,6 @@ public class TreeAnnotator {
         	return;
         }
 
-        
         if (targetOption != Target.USER_TARGET_TREE) {
             try {
             	treeSet.reset();
@@ -502,12 +509,26 @@ public class TreeAnnotator {
             cladeSystem.calculateCladeCredibilities(totalTreesUsed);
 
             progressStream.println("Total trees have " + totalTrees + ", where " + totalTreesUsed + " are used.");
-//            if (burninPercentage > 0) {
-//                progressStream.println("Ignoring first " + burninPercentage + "% trees.");
-//            }
 
             progressStream.println("Total unique clades: " + cladeSystem.getCladeMap().keySet().size());
             progressStream.println();
+        }  else {
+            // even when a user specificed target tree is provided we still need to count the totalTreesUsed for subsequent steps.
+            treeSet.reset();
+            while (treeSet.hasNext()) {
+                Tree tree = treeSet.next();
+                tree.getLeafNodeCount();
+                if (tree.getDirectAncestorNodeCount() > 0 && !SAmode) {
+                    SAmode = true;
+                    Log.err.println("A tree with a sampled ancestor is found. Turning on\n the sampled ancestor " +
+                            "summary analysis.");
+                    if (heightsOption == HeightsSummary.CA_HEIGHTS) {
+                        throw new RuntimeException("The common ancestor height is not \n available for trees with sampled " +
+                                "ancestors. Please choose \n another height summary option");
+                    }
+                }
+                totalTreesUsed++;
+            }
         }
 
         Tree targetTree = null;
@@ -555,13 +576,13 @@ public class TreeAnnotator {
         progressStream.println("0              25             50             75            100");
         progressStream.println("|--------------|--------------|--------------|--------------|");
 
-        stepSize = Math.max(totalTreesUsed / 60, 1);
+        int stepSize = Math.max(totalTreesUsed / 60, 1);
         int reported = 0;
 
         // this call increments the clade counts and it shouldn't
         // this is remedied with removeClades call after while loop below
         cladeSystem = new CladeSystem(targetTree);
-        int totalTreesUsed = 0;
+        int totalTreesUsedNew = 0;
         try {
             int counter = 0;
             treeSet.reset();
@@ -578,14 +599,13 @@ public class TreeAnnotator {
             	    }
                     progressStream.flush();
                 }
-                totalTreesUsed++;
+                totalTreesUsedNew++;
                 counter++;
         	}
         	
             cladeSystem.removeClades(targetTree.getRoot(), true);
-            //progressStream.println("totalTreesUsed=" + totalTreesUsed);
-            this.totalTreesUsed = totalTreesUsed;
-            cladeSystem.calculateCladeCredibilities(totalTreesUsed);
+            this.totalTreesUsed = totalTreesUsedNew;
+            cladeSystem.calculateCladeCredibilities(totalTreesUsedNew);
         } catch (Exception e) {
             Log.err.println("Error Parsing Input Tree: " + e.getMessage());
             return;
@@ -599,7 +619,7 @@ public class TreeAnnotator {
             annotateTree(cladeSystem, targetTree.getRoot(), null, heightsOption);
 
             if( heightsOption == HeightsSummary.CA_HEIGHTS ) {
-                setTreeHeightsByCA(targetTree);
+                setTreeHeightsByCA(targetTree, targetOption);
             }
         } catch (Exception e) {
         	e.printStackTrace();
@@ -639,7 +659,7 @@ public class TreeAnnotator {
 			processMetaData(child);
 		}
 		Set<String> metaDataNames = node.getMetaDataNames(); 
-		if (metaDataNames != null) {
+		if (metaDataNames != null && !metaDataNames.isEmpty()) {
 			String metadata = "";
 			for (String name : metaDataNames) {
 				Object value = node.getMetaData(name);
@@ -1291,6 +1311,8 @@ public class TreeAnnotator {
                     "</center></html>";
 
             new ConsoleApplication(nameString, aboutString, icon, true);
+            Log.info = System.out;
+            Log.err = System.err;
 
             // The ConsoleApplication will have overridden System.out so set progressStream
             // to capture the output to the window:
@@ -1488,7 +1510,7 @@ public class TreeAnnotator {
         boolean handleAttribute(Node node, String attributeName, double[] values);
     }
 
-    boolean setTreeHeightsByCA(Tree targetTree) throws IOException
+    boolean setTreeHeightsByCA(Tree targetTree, Target targetOption) throws IOException
              {
         progressStream.println("Setting node heights...");
         progressStream.println("0              25             50             75            100");
@@ -1552,7 +1574,10 @@ public class TreeAnnotator {
             counter++;
 
         }
-        targetTree.initAndValidate();
+
+        if (targetOption != Target.USER_TARGET_TREE)
+            targetTree.initAndValidate();
+
         cladeSystem.removeClades(targetTree.getRoot(), true);
         for (int k = 0; k < clades; ++k) {
             ths[k] /= totalTreesUsed;
