@@ -12,10 +12,11 @@ import beast.core.Input.Validate;
 import beast.core.Loggable;
 
 
-@Description("Logger to report height of a tree")
+@Description("Logger to report height of a tree -- deprecated: use TreeStatLogger instead")
+@Deprecated
 public class TreeHeightLogger extends CalculationNode implements Loggable, Function {
     final public Input<Tree> treeInput = new Input<>("tree", "tree to report height for.", Validate.REQUIRED);
-
+    
     @Override
     public void initAndValidate() {
         // nothing to do
@@ -37,7 +38,7 @@ public class TreeHeightLogger extends CalculationNode implements Loggable, Funct
         out.print(tree.getRoot().getHeight() + "\t");
     }
 
-    @Override
+	@Override
     public void close(PrintStream out) {
         // nothing to do
     }
