@@ -62,6 +62,7 @@ import beast.app.BEASTVersion2;
 import beast.app.beastapp.BeastMain;
 import beast.app.util.Arguments;
 import beast.app.util.Utils;
+import beast.core.BEASTInterface;
 import beast.core.Description;
 import beast.core.util.Log;
 import beast.evolution.alignment.Alignment;
@@ -218,7 +219,15 @@ public class AddOnManager {
                     packageMap.put(packageName, pkg);
                 }
 
+                if (addon.hasAttribute("projectURL"))
+                    pkg.setProjectURL(new URL(addon.getAttribute("projectURL")));
+
                 PackageVersion installedVersion = new PackageVersion(packageVersionString);
+
+                if (addon.hasAttribute("projectURL") &&
+                        !(pkg.getLatestVersion() != null && installedVersion.compareTo(pkg.getLatestVersion())<0))
+                    pkg.setProjectURL(new URL(addon.getAttribute("projectURL")));
+
                 Set<PackageDependency> installedVersionDependencies =
                         new TreeSet<>((o1, o2) -> o1.dependencyName.compareTo(o2.dependencyName));
 
@@ -307,8 +316,12 @@ public class AddOnManager {
                         pkg.setDescription(element.getAttribute("description"));
 
                         PackageVersion packageVersion = new PackageVersion(element.getAttribute("version"));
-                        Set<PackageDependency> packageDependencies = new HashSet<>();
 
+                        if (element.hasAttribute("projectURL") &&
+                                !(pkg.getLatestVersion() != null && packageVersion.compareTo(pkg.getLatestVersion())<0))
+                            pkg.setProjectURL(new URL(element.getAttribute("projectURL")));
+
+                        Set<PackageDependency> packageDependencies = new HashSet<>();
                         NodeList depNodes = element.getElementsByTagName("depends");
                         for (int j = 0; j < depNodes.getLength(); j++) {
                             Element dependson = (Element) depNodes.item(j);
@@ -818,13 +831,14 @@ public class AddOnManager {
         return dirs;
     } // getBeastDirectories
 
-    /**
+    
+
+	/**
      * load external jars in beast directories *
      */
     public static void loadExternalJars() throws IOException {
         processDeleteList();
 
-        TreeMap<String, Package> packages = new TreeMap<>();
         addInstalledPackages(packages);
 
         processInstallList(packages);
@@ -832,64 +846,79 @@ public class AddOnManager {
         checkInstalledDependencies(packages);
 
         for (String jarDirName : getBeastDirectories()) {
-            File versionFile = new File(jarDirName + "/version.xml");
-            if (versionFile.exists()) {
-                try {
-                    // print name and version of package
-                    DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
-                    Document doc = factory.newDocumentBuilder().parse(versionFile);
-                    Element addon = doc.getDocumentElement();
-                    Log.warning.println("Loading package " + addon.getAttribute("name") + " v" + addon.getAttribute("version"));
-                } catch (Exception e) {
-                	// too bad, won't print out any info
-                }
-            }
-            File jarDir = new File(jarDirName + "/lib");
-            if (!jarDir.exists()) {
-                jarDir = new File(jarDirName + "\\lib");
-            }
-            if (jarDir.exists() && jarDir.isDirectory()) {
-                for (String fileName : jarDir.list()) {
-                    if (fileName.endsWith(".jar")) {
-                        Log.debug.print("Probing: " + fileName + " ");
-                        // check that we are not reload existing classes
-                        String loadedClass = null;
-                        try {
-                            JarInputStream jarFile = new JarInputStream
-                                    (new FileInputStream(jarDir.getAbsolutePath() + "/" + fileName));
-                            JarEntry jarEntry;
+            try {
+                File versionFile = new File(jarDirName + "/version.xml");
+                String packageNameAndVersion = null;
+                if (versionFile.exists()) {
+                    try {
+                        // print name and version of package
+                        DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
+                        Document doc = factory.newDocumentBuilder().parse(versionFile);
+                        Element addon = doc.getDocumentElement();
+                        packageNameAndVersion = addon.getAttribute("name") + " v" + addon.getAttribute("version");
+                        Log.warning.println("Loading package " + packageNameAndVersion);
+                    } catch (Exception e) {
+                        // too bad, won't print out any info
 
-                            while (loadedClass == null) {
-                                jarEntry = jarFile.getNextJarEntry();
-                                if (jarEntry == null) {
-                                    break;
-                                }
-                                if ((jarEntry.getName().endsWith(".class"))) {
-                                    String className = jarEntry.getName().replaceAll("/", "\\.");
-                                    className = className.substring(0, className.lastIndexOf('.'));
-                                    try {
-                                        /*Object o =*/ Class.forName(className);
-                                        loadedClass = className;
-                                    } catch (Exception e) {
-                                        // TODO: handle exception
+                        // File is called version.xml, but is not a Beast2 version file
+                        // Log.debug.print("Skipping "+jarDirName+" (not a Beast2 package)");
+                    }
+                }
+                File jarDir = new File(jarDirName + "/lib");
+                if (!jarDir.exists()) {
+                    jarDir = new File(jarDirName + "\\lib");
+                }
+                if (jarDir.exists() && jarDir.isDirectory()) {
+                    for (String fileName : jarDir.list()) {
+                        if (fileName.endsWith(".jar")) {
+                            Log.debug.print("Probing: " + fileName + " ");
+                            // check that we are not reload existing classes
+                            String loadedClass = null;
+                            try {
+                                JarInputStream jarFile = new JarInputStream
+                                        (new FileInputStream(jarDir.getAbsolutePath() + "/" + fileName));
+                                JarEntry jarEntry;
+
+                                while (loadedClass == null) {
+                                    jarEntry = jarFile.getNextJarEntry();
+                                    if (jarEntry == null) {
+                                        break;
+                                    }
+                                    if ((jarEntry.getName().endsWith(".class"))) {
+                                        String className = jarEntry.getName().replaceAll("/", "\\.");
+                                        className = className.substring(0, className.lastIndexOf('.'));
+                                        try {
+                                            /*Object o =*/
+                                            Class.forName(className);
+                                            loadedClass = className;
+                                        } catch (Exception e) {
+                                            // TODO: handle exception
+                                        }
+                                        if (loadedClass == null && packageNameAndVersion != null) {
+                                            classToPackageMap.put(className, packageNameAndVersion);
+                                        }
                                     }
                                 }
+                                jarFile.close();
+                            } catch (Exception e) {
+                                e.printStackTrace();
                             }
-                            jarFile.close();
-                        } catch (Exception e) {
-                            e.printStackTrace();
-                        }
 
 
-                        @SuppressWarnings("deprecation")
-                        URL url = new File(jarDir.getAbsolutePath() + "/" + fileName).toURL();
-                        if (loadedClass == null) {
-                            addURL(url);
-                        } else {
-                            Log.debug.println("Skip loading " + url + ": contains class " + loadedClass + " that is already loaded");
+                            @SuppressWarnings("deprecation")
+                            URL url = new File(jarDir.getAbsolutePath() + "/" + fileName).toURL();
+                            if (loadedClass == null) {
+                                addURL(url);
+                            } else {
+                                Log.debug.println("Skip loading " + url + ": contains class " + loadedClass + " that is already loaded");
+                            }
                         }
                     }
                 }
+            } catch (Exception e) {
+                // File exists, but cannot open the file for some reason
+                Log.debug.println("Skipping "+jarDirName+"/version.xml (unable to open file");
+                Log.warning.println("Skipping "+jarDirName+"/version.xml (unable to open file");
             }
         }
         externalJarsLoaded = true;
@@ -1376,7 +1405,7 @@ public class AddOnManager {
 
         // Define headers here - need to know lengths
         String nameHeader = "Name";
-        String statusHeader = "Installation Status";
+        String statusHeader = "Installed Version";
         String latestHeader = "Latest Version";
         String depsHeader = "Dependencies";
         String descriptionHeader = "Description";
@@ -1395,7 +1424,7 @@ public class AddOnManager {
             packageList.add(pkg);
 
             maxNameWidth = Math.max(pkg.getName().length(), maxNameWidth);
-            maxStatusWidth = Math.max(pkg.getStatusString().length(), maxStatusWidth);
+            maxStatusWidth = Math.max(pkg.isInstalled() ? pkg.getInstalledVersion().toString().length() : 2, maxStatusWidth);
             maxLatestWidth = Math.max(maxLatestWidth, pkg.isAvailable()
                             ? pkg.getLatestVersion().toString().length()
                             :  Math.max(2, maxStatusWidth));
@@ -1429,7 +1458,7 @@ public class AddOnManager {
         for (Package pkg : packageList) {
         	if (pkg.getName().equals(BEAST_PACKAGE_NAME)) {
         		ps.printf(nameFormat, pkg.getName()); ps.print(sep);
-		        ps.printf(statusFormat, pkg.getStatusString()); ps.print(sep);
+		        ps.printf(statusFormat, pkg.isInstalled() ? pkg.getInstalledVersion() : "NA"); ps.print(sep);
 		        ps.printf(latestFormat, pkg.isAvailable() ? pkg.getLatestVersion() : "NA"); ps.print(sep);
 		        ps.printf(depsFormat, pkg.getDependenciesString()); ps.print(sep);
 		        ps.printf("%s\n", pkg.getDescription());
@@ -1443,7 +1472,7 @@ public class AddOnManager {
         for (Package pkg : packageList) {
         	if (!pkg.getName().equals(BEAST_PACKAGE_NAME)) {
 	            ps.printf(nameFormat, pkg.getName()); ps.print(sep);
-	            ps.printf(statusFormat, pkg.getStatusString()); ps.print(sep);
+	            ps.printf(statusFormat, pkg.isInstalled() ? pkg.getInstalledVersion() : "NA"); ps.print(sep);
 	            ps.printf(latestFormat, pkg.isAvailable() ? pkg.getLatestVersion() : "NA"); ps.print(sep);
 	            ps.printf(depsFormat, pkg.getDependenciesString()); ps.print(sep);
 	            ps.printf("%s\n", pkg.getDescription());
@@ -1578,4 +1607,58 @@ public class AddOnManager {
             e.printStackTrace();
         }
     }
+
+    /** keep track of which class comes from a particular package.
+     * It maps a full class name onto a package name + " v" + package version
+     * e.g. "bModelTest v0.3.2"
+     */
+    private static Map<String, String> classToPackageMap = new HashMap<>();
+    
+    /**  maps package name to a Package object, which contains info on whether 
+     * and which version is installed. This is initialised when loadExternalJars()
+     * is called, which happens at the start of BEAST, BEAUti and many utilities.
+     */
+    private static TreeMap<String, Package> packages = new TreeMap<>();
+
+    /** return set of Strings in the format of classToPackageMap (like "bModelTest v0.3.2")
+     * for all packages used by o and its predecessors in the model graph.
+     */
+    public static Set<String> getPackagesAndVersions(BEASTInterface o) {
+    	Set<String> packagesAndVersions = new LinkedHashSet<>();
+    	getPackagesAndVersions(o, packagesAndVersions);
+    	return packagesAndVersions;
+    }
+    
+    /** traverse model graph starting at o, and collect packageAndVersion strings
+     * along the way.
+     */
+    private static void getPackagesAndVersions(BEASTInterface o, Set<String> packagesAndVersions) {
+    	String packageAndVersion = classToPackageMap.get(o.getClass().getName());
+    	if (packageAndVersion != null) {
+    		packagesAndVersions.add(packageAndVersion);
+    	}
+    	for (BEASTInterface o2 : o.listActiveBEASTObjects()) {
+    		getPackagesAndVersions(o2, packagesAndVersions);
+    	}
+	}
+
+    /** test whether a package with given name and version is available.
+     * @param pkgname
+     * @param pkgversion ignored for now
+     * @return
+     */
+    // RRB: may need to return PackageStatus instead of boolean, but not sure yet how to handle
+    // the case where a newer package is installed, and the old one is not available yet.
+    //public static enum PackageStatus {NOT_INSTALLED, INSTALLED, INSTALLED_VERSION_NOT_AVAILABLE};
+    public static boolean isInstalled(String pkgname, String pkgversion) {
+		if (!packages.containsKey(pkgname)) {
+			return false;
+		}
+		return true;
+//		Package pkg = packages.get(pkgname);
+//		PackageVersion version = new PackageVersion(pkgversion);
+//		if (pkg.isAvailable(version)) {
+//			return false;
+//		}
+	}
  }
