@@ -164,7 +164,8 @@ public class TreeParser extends Tree implements StateNodeInitialiser {
         }
 
         super.initAndValidate();
-        
+        m_sTaxaNames = null;
+
         if (sortNodesAlphabetically) {
 	        // correct for node ordering: ensure order is alphabetical
 	        for (int i = 0; i < getNodeCount() && i < labels.size(); i++) {
@@ -467,8 +468,22 @@ public class TreeParser extends Tree implements StateNodeInitialiser {
                                 stringValue = stringValue.substring(1, stringValue.length()-1);
                             }
                             node.setMetaData(key, stringValue);
-                        } else {
-                            // BEAST doesn't do anything with vectors yet.
+                        } else if (attribctx.attribValue().vector() != null) {
+                            try {
+
+                                List<NewickParser.AttribValueContext> elementContexts = attribctx.attribValue().vector().attribValue();
+
+                                Double[] values = new Double[elementContexts.size()];
+                                for (int i = 0; i < elementContexts.size(); i++)
+                                    values[i] = Double.parseDouble(elementContexts.get(i).getText());
+
+                                node.setMetaData(key, values);
+
+                            } catch (NumberFormatException ex) {
+                                throw new ParseCancellationException("Encountered vector-valued metadata entry with " +
+                                        "one or more non-numeric elements.");
+                            }
+
                         }
                     }
                 }
@@ -491,10 +506,6 @@ public class TreeParser extends Tree implements StateNodeInitialiser {
                         || postCtx.label().number().INT() == null)
                     integerLeafLabels = false;
 
-                // RRB: next line is for debugging only?
-                @SuppressWarnings("unused")
-				String postText = postCtx.getText();
-
                 // Treat labels as node numbers in certain situations
                 if (!isLabelledNewickInput.get()
                         && postCtx.label().number() != null
